/* -*- C++ -*-
 *
 * This file is a part of LEMON, a generic C++ optimization library
 *
 * Copyright (C) 2003-2006
 * Egervary Jeno Kombinatorikus Optimalizalasi Kutatocsoport
 * (Egervary Research Group on Combinatorial Optimization, EGRES).
 *
 * Permission to use, modify and distribute this software is granted
 * provided that this copyright notice appears in all copies. For
 * precise terms see the accompanying LICENSE file.
 *
 * This software is provided "AS IS" with no warranty of any kind,
 * express or implied, and with no claim as to its suitability for any
 * purpose.
 *
 */

#ifndef LEMON_SMART_UGRAPH_H
#define LEMON_SMART_UGRAPH_H

///\ingroup graphs
///\file
///\brief SmartUGraph class.

#include <vector>

#include <lemon/bits/invalid.h>

#include <lemon/smart_graph.h>
#include <lemon/bits/base_extender.h>
#include <lemon/bits/ugraph_extender.h>

#include <lemon/bits/utility.h>
#include <lemon/error.h>

#include <lemon/bits/graph_extender.h>

namespace lemon {


  typedef UGraphExtender<UndirGraphExtender<SmartGraphBase> >
  ExtendedSmartUGraphBase;

  /// \ingroup graphs
  ///
  /// \brief A smart undirected graph class.
  ///
  /// This is a simple and fast undirected graph implementation.
  /// It is also quite memory efficient, but at the price
  /// that <b> it does support only limited (only stack-like)
  /// node and edge deletions</b>.
  /// Except from this it conforms to 
  /// the \ref concept::UGraph "UGraph" concept.
  /// \sa concept::UGraph.
  ///
  /// \todo Snapshot hasn't been implemented yet.
  ///
  class SmartUGraph : public ExtendedSmartUGraphBase {
  };


  
  /// @}  
} //namespace lemon


#endif //LEMON_SMART_GRAPH_H
